@@ -4,8 +4,9 @@ import pickle
 import numpy as np
 import pylab as pp
 import scipy.ndimage as SCI
-
 import tables as Tab
+import h5py 
+
 if Tab.__version__ >= "3.4.3":
     Tab.openFile = Tab.open_file
     Tab.File.createGroup = Tab.File.create_group
@@ -13,11 +14,13 @@ if Tab.__version__ >= "3.4.3":
     Tab.File.createArray = Tab.File.create_array
 
 if sys.version_info.major == 3:
-    from . import generaltools as GT
-    from . import readmccd as RMCCD
-    from . import IOLaueTools as IOLT
-    from . import dict_LaueTools as DictLT
-    from . import orientations as ORI
+    #from . import generaltools as GT
+    
+    import LaueTools.generaltools as GT
+    import LaueTools.readmccd as RMCCD
+    import LaueTools.IOLaueTools as IOLT
+    import LaueTools.dict_LaueTools as DictLT
+    import LaueTools.orientations as ORI
 else:
 
     import generaltools as GT
@@ -225,11 +228,11 @@ pos_voigt = [0, 4, 8, 5, 2, 1]
 #    filename = "testdict.h5"
 #    imagefilename_prefix = 'tsv1234_'
 #    # Open a file in "w"rite mode
-#    h5file = Tab.openFile(filename, mode="w", title="Test file my data")
+#     = Tab.openFile(filename, mode="w", title="Test file my data")
 #    # Create a new group under "/" (root)
-#    group_images = h5file.createGroup("/", 'Images', 'Detector information')
+#    group_images = .createGroup("/", 'Images', 'Detector information')
 #    # Create one table on it
-#    table = h5file.createTable(group_images, 'matching_rate_Si', IndexedImage, "Readout example")
+#    table = h5file.create_table(group_images, 'matching_rate_Si', IndexedImage, "Readout example")
 #    # Fill the table with 10 particles
 #    indexedImage = table.row
 #    keys_indexfile = dictMat.keys()[:200]
@@ -243,7 +246,7 @@ pos_voigt = [0, 4, 8, 5, 2, 1]
 #        indexedImage.append()
 #
 #        group_spots = h5file.createGroup("/Images", 'spots%06d' % key_image, 'experimental spots information')
-#        table_spots = h5file.createTable(group_spots, 'spots_table', SpotsList, "spots table list")
+#        table_spots = h5file.create_table(group_spots, 'spots_table', SpotsList, "spots table list")
 #        spotslist = table_spots.row
 #        for elem in dictspots[key_image][0]:  # 1 grain
 #            spotslist['spotindex'] = elem[0]
@@ -256,7 +259,7 @@ pos_voigt = [0, 4, 8, 5, 2, 1]
 #
 #    group_spots = h5file.createGroup("/", 'Allspots', 'All spots information')
 #
-#    tableallspots = h5file.createTable(group_spots, 'total_spots', AllIndexedSpots, "Readout example")
+#    tableallspots = h5file.create_table(group_spots, 'total_spots', AllIndexedSpots, "Readout example")
 #    # Fill the table with 10 particles
 #    allIndexedSpots = tableallspots.row
 #    keys_indexfile = dictMat.keys()
@@ -334,16 +337,19 @@ def build_hdf5( filename_dictRes, dirname_dictRes=None, output_hdf5_filename="di
 
     # Open a file in "w"rite mode
     full_output_path = os.path.join(output_dirname, output_hdf5_filename)
-    h5file = Tab.openFile(full_output_path, mode="w", title="%s" % imagefilename_prefix)
+    #h5file = Tab.openFile(full_output_path, mode="w", title="%s" % imagefilename_prefix)
+    h5file = Tab.open_file(full_output_path, mode="w", title="%s" % imagefilename_prefix)
 
     keys_indexfile = keys_indexfile[:nb_of_images]
     # ----------------------------------------
     if 1:  # Class IndexedImage
         # Create a new group under "/" (root)
-        group_images = h5file.createGroup("/", "Indexation", "Indexation figure")
+        #group_images = h5file.createGroup("/", "Indexation", "Indexation figure")
+        group_images = h5file.create_group("/", "Indexation", "Indexation figure")
+
 
         # Create one table on it
-        table = h5file.createTable(group_images, "matching_rate", IndexedImage, "indexation rate")
+        table = h5file.create_table(group_images, "matching_rate", IndexedImage, "indexation rate")
         # Fill the table with data
         indexedImage = table.row
 
@@ -370,7 +376,7 @@ def build_hdf5( filename_dictRes, dirname_dictRes=None, output_hdf5_filename="di
         #        group_images = h5file.createGroup("/", 'Indexation', 'Indexation figure')
 
         # Create one table on it
-        tableUB = h5file.createTable(group_images, "UB_matrices", Matrices, "UB Matrices elements")
+        tableUB = h5file.create_table(group_images, "UB_matrices", Matrices, "UB Matrices elements")
         # Fill the table with data
         indexedUB = tableUB.row
         print("using Lauehdf5.....")
@@ -411,7 +417,7 @@ def build_hdf5( filename_dictRes, dirname_dictRes=None, output_hdf5_filename="di
         #        group_images = h5file.createGroup("/", 'Indexation', 'Indexation figure')
 
         # Create one table on it
-        tableUB_array = h5file.createTable(group_images, "UB_matrices_array", Matrices_array,
+        tableUB_array = h5file.create_table(group_images, "UB_matrices_array", Matrices_array,
                                                                             "UB Matrices elements")
         # Fill the table with data
         indexedUB_ar = tableUB_array.row
@@ -441,7 +447,7 @@ def build_hdf5( filename_dictRes, dirname_dictRes=None, output_hdf5_filename="di
         #        group_images = h5file.createGroup("/", 'Indexation', 'Indexation figure')
 
         # Create one table on it
-        tabledev = h5file.createTable(group_images, "Devstrain_matrices", DevStrain,
+        tabledev = h5file.create_table(group_images, "Devstrain_matrices", DevStrain,
                                                                             "UB Matrices elements")
         # Fill the table with data
         indexedDev = tabledev.row
@@ -475,10 +481,10 @@ def build_hdf5( filename_dictRes, dirname_dictRes=None, output_hdf5_filename="di
 
     if 1:  # Class DevStrain  sample frame
         #        # Create a new group under "/" (root)
-        #        group_images = h5file.createGroup("/", 'Indexation', 'Indexation figure')
+        #        group_images = h5file.create_group("/", 'Indexation', 'Indexation figure')
 
         # Create one table on it
-        tabledevS = h5file.createTable(group_images, "DevstrainSample_matrices", DevStrainSample,
+        tabledevS = h5file.create_table(group_images, "DevstrainSample_matrices", DevStrainSample,
                                                                             "UB Matrices elements")
         # Fill the table with data
         indexedDevS = tabledevS.row
@@ -513,9 +519,9 @@ def build_hdf5( filename_dictRes, dirname_dictRes=None, output_hdf5_filename="di
 
     if 1:  # class AllIndexedSpots
 
-        group_spots = h5file.createGroup("/", "Allspots", "All spots information")
+        group_spots = h5file.create_group("/", "Allspots", "All spots information")
 
-        tableallspots = h5file.createTable(group_spots,
+        tableallspots = h5file.create_table(group_spots,
                                             "total_spots",
                                             AllIndexedSpots,
                                             "Readout example",
@@ -637,9 +643,9 @@ def Add_allspotsSummary_from_dict( Summary_HDF5_filename, filename_dictRes,
 
     keys_indexfile = keys_indexfile[:nb_of_images]
 
-    group_spots = h5file.createGroup("/", "Allspots", "All spots information")
+    group_spots = h5file.create_group("/", "Allspots", "All spots information")
 
-    tableallspots = h5file.createTable(group_spots, "total_spots", AllIndexedSpots,
+    tableallspots = h5file.create_table(group_spots, "total_spots", AllIndexedSpots,
                                                 "Readout example",
                                                 expectedrows=nb_of_images * nb_of_spots_per_image)
 
@@ -729,57 +735,57 @@ def Add_allspotsSummary_from_fitfiles( Summary_HDF5_filename, prefix_fitfiles, f
         full_HDF5_output_path = os.path.join(Summary_HDF5_dirname, Summary_HDF5_filename)
 
     # Open a file in 'append' mode
-    h5file = Tab.openFile(full_HDF5_output_path, mode="a", title="%s" % "allspots")
+    h5file = Tab.open_file(full_HDF5_output_path, mode="a", title="%s" % "allspots")
 
     nb_of_images = len(fileindex_list)
 
     try:
-        tableallspots = h5file.getNode("/Allspots/total_spots")
+        tableallspots = h5file.get_node("/Allspots/total_spots")
         Node_tableallspots_alreadyExists = True
     except Tab.NodeError:
         Node_tableallspots_alreadyExists = False
 
     if not Node_tableallspots_alreadyExists:
 
-        group_spots = h5file.createGroup("/", "Allspots", "All spots information")
-        tableallspots = h5file.createTable( group_spots, "total_spots", AllIndexedSpots,
+        group_spots = h5file.create_group("/", "Allspots", "All spots information")
+        tableallspots = h5file.create_table( group_spots, "total_spots", AllIndexedSpots,
                                     "Readout example",
                                     expectedrows=max(nb_of_images * nb_of_spots_per_image, 10000))
 
     allIndexedSpots = tableallspots.row
 
     try:
-        table = h5file.getNode("/Indexation/matching_rate")
+        table = h5file.get_node("/Indexation/matching_rate")
         Node_tableimage_alreadyExists = True
     except Tab.NodeError:
         Node_tableimage_alreadyExists = False
 
     if not Node_tableimage_alreadyExists:
 
-        group_images = h5file.createGroup("/", "Indexation", "Indexation figure")
-        table = h5file.createTable(group_images, "matching_rate", IndexedImage, "indexation rate")
+        group_images = h5file.create_group("/", "Indexation", "Indexation figure")
+        table = h5file.create_table(group_images, "matching_rate", IndexedImage, "indexation rate")
 
     indexedImage = table.row
 
     try:
-        tableUB = h5file.getNode("/Indexation/UB_matrices_LT")
+        tableUB = h5file.get_node("/Indexation/UB_matrices_LT")
         Node_tableUB_alreadyExists = True
     except Tab.NodeError:
         Node_tableUB_alreadyExists = False
 
     if not Node_tableUB_alreadyExists:
-        tableUB = h5file.createTable(group_images, "UB_matrices_LT", Matrices, "UB Matrices elements")
+        tableUB = h5file.create_table(group_images, "UB_matrices_LT", Matrices, "UB Matrices elements")
 
     indexedUB = tableUB.row
 
     try:
-        tableUB_sample = h5file.getNode("/Indexation/UB_matrices_SampleFrame")
+        tableUB_sample = h5file.get_node("/Indexation/UB_matrices_SampleFrame")
         Node_tableUB_alreadyExists = True
     except Tab.NodeError:
         Node_tableUB_alreadyExists = False
 
     if not Node_tableUB_alreadyExists:
-        tableUB_sample = h5file.createTable(group_images, "UB_matrices_SampleFrame", Matrices,
+        tableUB_sample = h5file.create_table(group_images, "UB_matrices_SampleFrame", Matrices,
                                                                             "UB Matrices elements")
 
     indexedUB_sample = tableUB_sample.row
@@ -806,7 +812,7 @@ def Add_allspotsSummary_from_fitfiles( Summary_HDF5_filename, prefix_fitfiles, f
                 # rows = self.tableallspots.getWhereList('fileindex == %d' % fileindex)
                 rowpos = np.where(allindices == fileindex)[0]
                 for row_to_delete in rowpos:
-                    tableallspots.removeRows(row_to_delete)
+                    tableallspots.remove_rows(row_to_delete)
 
         _filename = prefix_fitfiles + encodingdigits % fileindex + filesuffix
 
@@ -826,18 +832,11 @@ def Add_allspotsSummary_from_fitfiles( Summary_HDF5_filename, prefix_fitfiles, f
         #         print "resIndexed", resIndexed
 
         if resIndexed != 0:
-            (list_indexedgrains_indices,
-                list_nb_indexed_peaks,
-                list_starting_rows_in_data,
-                all_UBmats_flat,
-                allgrains_spotsdata,
-                calibJSM,
-                list_pixdev,
-                list_strain6,
-                list_euler,
-            ) = resIndexed
+            (list_indexedgrains_indices, list_nb_indexed_peaks, list_starting_rows_in_data,
+                all_UBmats_flat, allgrains_spotsdata, calibJSM,
+                list_pixdev, list_strain6, list_euler, ) = resIndexed
 
-            print("list_pixdev", list_pixdev)
+            print("read hdf5 : list_pixdev", list_pixdev)
             if len(list_pixdev) == 0:
                 print("setting pixdev to -1 for file: %s" % _filename)
                 list_pixdev = [-1 for kkk in range(len(list_indexedgrains_indices))]
@@ -855,13 +854,9 @@ def Add_allspotsSummary_from_fitfiles( Summary_HDF5_filename, prefix_fitfiles, f
 
                 (allIndexedSpots["spotindex"],
                     allIndexedSpots["intensity"],
-                    allIndexedSpots["H"],
-                    allIndexedSpots["K"],
-                    allIndexedSpots["L"],
-                    allIndexedSpots["twotheta"],
-                    allIndexedSpots["chi"],
-                    allIndexedSpots["pixX"],
-                    allIndexedSpots["pixY"],
+                    allIndexedSpots["H"], allIndexedSpots["K"], allIndexedSpots["L"],
+                    allIndexedSpots["twotheta"], allIndexedSpots["chi"],
+                    allIndexedSpots["pixX"], allIndexedSpots["pixY"],
                     allIndexedSpots["energy"],
                     allIndexedSpots["grainindex"],
                     allIndexedSpots["PixDev"],
@@ -932,15 +927,11 @@ def Add_allspotsSummary_from_fitfiles( Summary_HDF5_filename, prefix_fitfiles, f
 
             (allIndexedSpots["spotindex"],
                 allIndexedSpots["intensity"],
-                allIndexedSpots["twotheta"],
-                allIndexedSpots["chi"],
-                allIndexedSpots["pixX"],
-                allIndexedSpots["pixY"],
+                allIndexedSpots["twotheta"], allIndexedSpots["chi"],
+                allIndexedSpots["pixX"], allIndexedSpots["pixY"],
             ) = spot_data
 
-            (allIndexedSpots["H"],
-                allIndexedSpots["K"],
-                allIndexedSpots["L"],
+            (allIndexedSpots["H"], allIndexedSpots["K"], allIndexedSpots["L"],
                 allIndexedSpots["energy"],
                 allIndexedSpots["grainindex"],
                 allIndexedSpots["PixDev"],
@@ -974,6 +965,8 @@ def Add_allspotsSummary_from_fitfiles( Summary_HDF5_filename, prefix_fitfiles, f
     # Close (and flush) the file
     h5file.close()
 
+    print('Summary file is built!: %s'%full_HDF5_output_path)
+
 
 def build_hdf5_fromSummaryFile(
     Summaryfilename="/home/micha/LaueTools/UO2_20_90_serree__SUMMARY_0_to_609_add_columns.dat",
@@ -1035,10 +1028,10 @@ def build_hdf5_fromSummaryFile(
     # ----------------------------------------
     if 1:  # Class IndexedImage
         # Create a new group under "/" (root)
-        group_images = h5file.createGroup("/", "Indexation", "Indexation figure")
+        group_images = h5file.create_group("/", "Indexation", "Indexation figure")
 
         # Create one table on it
-        table = h5file.createTable(group_images, "matching_rate", IndexedImage, "indexation rate")
+        table = h5file.create_table(group_images, "matching_rate", IndexedImage, "indexation rate")
         # Fill the table with data
         indexedImage = table.row
 
@@ -1069,10 +1062,10 @@ def build_hdf5_fromSummaryFile(
     # ----------------------------------------
     if 1:  # Class Matrices
         #        # Create a new group under "/" (root)
-        #        group_images = h5file.createGroup("/", 'Indexation', 'Indexation figure')
+        #        group_images = h5file.create_group("/", 'Indexation', 'Indexation figure')
 
         # Create one table on it
-        tableUB = h5file.createTable(group_images,
+        tableUB = h5file.create_table(group_images,
                                     "UB_matrices",
                                     Matrices,
                                     "matstarlab UB Matrices elements in OR frame")
@@ -1107,10 +1100,10 @@ def build_hdf5_fromSummaryFile(
     # test
     if 1:  # Class Matrices_array
         #        # Create a new group under "/" (root)
-        #        group_images = h5file.createGroup("/", 'Indexation', 'Indexation figure')
+        #        group_images = h5file.create_group("/", 'Indexation', 'Indexation figure')
 
         # Create one table on it
-        tableUB_array = h5file.createTable(group_images, "UB_matrices_array", Matrices_array,
+        tableUB_array = h5file.create_table(group_images, "UB_matrices_array", Matrices_array,
                                                                             "UB Matrices elements")
         # Fill the table with data
         indexedUB_ar = tableUB_array.row
@@ -1139,10 +1132,10 @@ def build_hdf5_fromSummaryFile(
 
     if 1:  # Class DevStrain
         #        # Create a new group under "/" (root)
-        #        group_images = h5file.createGroup("/", 'Indexation', 'Indexation figure')
+        #        group_images = h5file.create_group("/", 'Indexation', 'Indexation figure')
 
         # Create one table on it
-        tabledev = h5file.createTable(group_images, "Deviatoric_strain", DevStrain, "voigt notation")
+        tabledev = h5file.create_table(group_images, "Deviatoric_strain", DevStrain, "voigt notation")
         # Fill the table with data
         indexedDev = tabledev.row
 
@@ -1262,20 +1255,32 @@ class TableMap:
         self.peaklistcor_extension = PEAKLISTCOR_EXTENSION
 
     def readfile(self, filename, modify=1):
-        self.hdf = ReadMapFile(filename, modify=modify)
+        """ read hdf5 file and look for Laue analysis data """
+        self.hdf = ReadMapFile(filename, modify=0)
+
+        print('self.hdf %s'%self.hdf)
+
+        # self.tableallspotsNode = "/Allspots/total_spots"
+        # self.tableUBNode = "/Indexation/UB_matrices"
+        # self.tableMRNode = "/Indexation/matching_rate"
+
+        # self.tableallspotsNode = self.hdf["/Allspots/total_spots"]
+        # self.tableUBNode = self.hdf["/Indexation/UB_matrices"]
+        # self.tableMRNode = self.hdf["/Indexation/matching_rate"]
+
         try:
-            self.tableallspotsNode = self.hdf.getNode("/Allspots/total_spots")
+            self.tableallspotsNode = self.hdf.get_node("/Allspots/total_spots")
         except Tab.NoSuchNodeError:
             print("Missing Node containing spots Data")
             self.tableallspotsNode = None
 
         try:
-            self.tableUBNode = self.hdf.getNode("/Indexation/UB_matrices_LT")
+            self.tableUBNode = self.hdf.get_node("/Indexation/UB_matrices")
         except Tab.NoSuchNodeError:
             print("Missing Node containing UB matrix data")
             self.tableUBNode = None
         try:
-            self.tableMRNode = self.hdf.getNode("/Indexation/matching_rate")
+            self.tableMRNode = self.hdf.get_node("/Indexation/matching_rate")
         except Tab.NoSuchNodeError:
             print("Missing Node containing spots Indexation Quality")
             self.tableMRNode = None
@@ -1291,16 +1296,15 @@ class TableMap:
         if self.tableallspotsNode is not None:
             self.field_Spots = self.tableallspotsNode.colnames
 
-        self.nb_images = self.tableUBNode.nrows
+        self.nb_images = self.tableUBNode.shape[0]
 
         print("nb of images", self.nb_images)
 
         print("reset manually nb of images to 1681 !!!")
-        self.nb_images = 1681
+        self.nb_images =500
         # TODO to be more general
         self.starting_index = min(self.tableMRNode.read(field="fileindex"))
-
-        self.final_index = self.tableUBNode.nrows
+        self.final_index = max(self.tableMRNode.read(field="fileindex"))
 
     # --- ------------  Query ------------------
     def peak_location(self, XY, radius=5.0, otherinfo=None):
@@ -1528,7 +1532,7 @@ class TableMap:
         """
         sentence = """fileindex == %d"""
 
-        queryanswer = self.tableMRNode.readWhere(sentence % fileindex)
+        queryanswer = self.tableMRNode.read_where(sentence % fileindex)
 
         #         print 'queryanswer',queryanswer
         if len(queryanswer) > 0:
@@ -1545,7 +1549,7 @@ class TableMap:
         """
         sentence = """fileindex == %d"""
 
-        queryanswer = self.tableMRNode.readWhere(sentence % fileindex)
+        queryanswer = self.tableMRNode.read_where(sentence % fileindex)
         if len(queryanswer) > 0:
             tupleelems = list(queryanswer[0])
 
@@ -1575,7 +1579,7 @@ class TableMap:
         """
         sentence = """fileindex == %d"""
 
-        queryanswer = self.tableMRNode.readWhere(sentence % fileindex)
+        queryanswer = self.tableMRNode.read_where(sentence % fileindex)
         if len(queryanswer) > 0:
             grainsNB = list(queryanswer[0])[3:6]
             # TODO check if the order is the same as tableMRNode.colnames
@@ -1603,7 +1607,7 @@ class TableMap:
 
         sentence = """fileindex == %d"""
 
-        queryanswer = self.tableUBNode.readWhere(sentence % fileindex)
+        queryanswer = self.tableUBNode.read_where(sentence % fileindex)
         #         print fileindex, queryanswer
         if len(queryanswer) > 0:
             tupleelems = list(queryanswer[0])[:-1]
@@ -1859,9 +1863,8 @@ class TableMap:
 
         print(self.kwds_fitpeaks)
 
-        params = RMCCD.readoneimage_multiROIfit(
-            filename, centers, boxsize, **self.kwds_fitpeaks
-        )[0]
+        params = RMCCD.readoneimage_multiROIfit(filename, centers, boxsize,
+                                    **self.kwds_fitpeaks)[0]
 
         par = np.array(params)
 
@@ -2014,8 +2017,7 @@ DEFAULT_DICT_NONINDEXEDSPOTS_VALUES = {"H": 10000,
                                         "PixDev_x": -1,
                                         "PixDev_y": -1}
 
-DEFAULT_TO_RESET = ([
-        DEFAULT_DICT_NONINDEXEDSPOTS_VALUES["H"],
+DEFAULT_TO_RESET = ([DEFAULT_DICT_NONINDEXEDSPOTS_VALUES["H"],
         DEFAULT_DICT_NONINDEXEDSPOTS_VALUES["K"],
         DEFAULT_DICT_NONINDEXEDSPOTS_VALUES["L"],
         DEFAULT_DICT_NONINDEXEDSPOTS_VALUES["MatchingRate"],
@@ -2036,7 +2038,10 @@ class TabletoQuery:
     def __init__(self, tableofdata, tabletypename):
         self.table = tableofdata
         self.fields = tableofdata.colnames
-        self.nbdata = tableofdata.nrows
+        nb_cols = len(self.fields)
+        nb_rows = tableofdata.nrows
+        # nb of rows or 'data'
+        self.nbdata = nb_rows
         self.tabletypename = tabletypename
 
     #        self.parenttable = parent.tableofdata
@@ -2414,13 +2419,18 @@ def ReadMap(hfd5_filename):
     return tableUB, tableMR, tableallspots
 
 
-def ReadMapFile(hfd5_filename, modify=1):
+def ReadMapFile(hfd5_filename, modify=0):
     print("opening hdf5 file: %s" % hfd5_filename)
 
     if modify:
         hdf5file = Tab.openFile(hfd5_filename, "a")
     else:
-        hdf5file = Tab.openFile(hfd5_filename)
+        hdf5file = Tab.openFile(hfd5_filename, 'r')
+
+    # if modify:
+    #     hdf5file = h5py.File(hfd5_filename, "a")
+    # else:
+    #     hdf5file = h5py.File(hfd5_filename)
 
     return hdf5file
 
