@@ -16,7 +16,6 @@ from __future__ import division
 
 import math
 import sys
-import builtins
 
 import numpy as np
 
@@ -24,6 +23,7 @@ np.set_printoptions(precision=15)
 
 # LaueTools modules
 if sys.version_info.major == 3:
+    import builtins
     from . import CrystalParameters as CP
     from . import generaltools as GT
     from . import IOLaueTools as IOLT
@@ -46,7 +46,7 @@ try:
 
     USE_CYTHON = True
 except ImportError:
-    print("Cython compiled module for fast computation of Laue spots is not installed!")
+    #print("-- warning. Cython compiled module for fast computation of Laue spots is not installed!")
     USE_CYTHON = False
 
 DEG = np.pi / 180.0
@@ -491,6 +491,11 @@ def getLaueSpots(wavelmin, wavelmax, crystalsParams, kf_direction=DEFAULT_TOP_GE
 
         table_vec = table_vec[cond_Xnegativeonly]
 
+        if sys.version_info.major == 3:
+            listObj = builtins.list
+        else:
+            listObj = list
+
         # Kf direction selection
         # top reflection 2theta = 90
         if kf_direction == "Z>0":
@@ -501,11 +506,11 @@ def getLaueSpots(wavelmin, wavelmax, crystalsParams, kf_direction=DEFAULT_TOP_GE
         # side reflection  2theta = 90
         elif kf_direction == "Y<0":
             KF_condit = listrotvec_Y < 0
-        
+
         # x > -R transmission 2theta = 0
         elif kf_direction == "X>0":
             KF_condit = (listrotvec_X + 1.0 / (2.0 * np.abs(listrotvec_X) / arraysquare) > 0)
-        
+
         # x < -R back reflection 2theta = 180
         elif kf_direction == "X<0":
             KF_condit = (listrotvec_X + 1.0 / (2.0 * np.abs(listrotvec_X) / arraysquare) < 0)
@@ -514,7 +519,7 @@ def getLaueSpots(wavelmin, wavelmax, crystalsParams, kf_direction=DEFAULT_TOP_GE
             KF_condit = np.ones_like(listrotvec_X) * True
         # user's definition of mean kf vector
         # [2theta , chi]= / kf = [cos2theta,sin2theta*sinchi,sin2theta*coschi]
-        elif isinstance(kf_direction, (builtins.list, np.array)):
+        elif isinstance(kf_direction, (listObj, np.array)):
             print("\nUSING user defined LauePattern Region\n")
             if len(kf_direction) != 2:
                 raise ValueError("kf_direction must be defined by a list of two angles !")
@@ -1813,7 +1818,8 @@ def SimulateLaue_full_np(grain, emin, emax, detectorparameters, kf_direction=DEF
                                                                 dim=(2048, 2048),
                                                                 detectordiameter=None,
                                                                 force_extinction=None,
-                                                                dictmaterials=dict_Materials):
+                                                                dictmaterials=dict_Materials,
+                                                                verbose=0):
     r"""Compute Laue Pattern spots positions, scattering angles, miller indices
                             for a SINGLE grain or Xtal using numpy vectorization
 
@@ -1875,7 +1881,7 @@ def SimulateLaue_full_np(grain, emin, emax, detectorparameters, kf_direction=DEF
     if removeharmonics:
         # remove harmonics:
         _, _, tokeep = GT.removeClosePoints(posx, posy, 0.05)
-        print('removeharmonics = 1 in SimulateLaue_full_np() tokeep',tokeep)
+        if verbose: print('removeharmonics = 1 in SimulateLaue_full_np() tokeep',tokeep)
 
         s_tth = Twicetheta[tokeep]
         s_chi = Chi[tokeep]
